%bcond_with check

Summary: Transform Linux Audit logs for SIEM usage 
Name: laurel
Version: 0.7.2
Release: 1%{?dist}
License: GPL3
URL: https://github.com/threathunters-io/laurel
Source0: laurel-%{version}.tar.gz
Source1: vendor.tar.gz
Source2: laurel.conf
Source3: config.toml
# SBOM
Source4: laurel-%{version}-cyclonedx-json
Source5: laurel-%{version}-spdx-json
# reduces BR
# BuildRequires: pandoc make
Source6: laurel-%{version}-manpages.tar.gz

%if 0%{?rhel} == 7
BuildRequires: llvm-toolset-14.0
BuildRequires: rust-toolset >= 1.72.1
%endif

%if 0%{?rhel} == 8
BuildRequires: rust-toolset >= 1.79.0
BuildRequires: clang
%endif

%if 0%{?fedora} || 0%{?rhel} == 9
#BuildRequires: rust-toolset >= 1.75.0
BuildConflicts: rust-toolset
BuildRequires: cargo-rpm-macros >= 26
BuildRequires: clang
%endif

%if 0%{?rhel} == 10
BuildRequires: rust-toolset >= 1.79.0
BuildRequires: clang
%endif

BuildRequires: libacl-devel

%description
LAUREL is an event post-processing plugin for auditd(8) that generates useful, 
enriched JSON-based audit logs suitable for modern security monitoring setups.

%prep

%setup -q -a1 -a6

%if 0%{?rhel} == 7
source /opt/rh/llvm-toolset-14.0/enable
%endif

%cargo_prep

# to download the deps, type "cargo vendor" and make a tar ball of the vendor directory

# generate SBOM files
#syft vendor -o spdx-json > laurel-%{version}-spdx-json
#syft vendor -o cyclonedx-json > laurel-%{version}-cyclonedx-json

%if 0%{?rhel} == 7
cat >> .cargo/config << EOF

[net]
offline = true

[source.local-registry]
directory = "/usr/share/cargo/registry"

[source.crates-io]

replace-with = "vendored-sources"

[source.vendored-sources]
directory = "vendor"
EOF

cat >> Cargo << EOF
[profile.release]
lto = true
EOF
%endif

%if 0%{?rhel} == 8
# some weird shit here
sed -i "s|^registry.*||g" .cargo/config.toml
sed -i "s|^replace-with.*|replace-with = \"vendored-sources\"|g" .cargo/config.toml
sed -i "s|^directory = \"\"|directory = \"vendor\"|g" .cargo/config.toml

cat >> Cargo.toml << EOF
[profile.release]
lto = true
EOF
%endif

%if 0%{?fedora} || 0%{?rhel} == 9
# some weird shit here
sed -i "s|^registry.*||g" .cargo/config.toml
sed -i "s|^replace-with.*|replace-with = \"vendored-sources\"|g" .cargo/config.toml

cat >> .cargo/config.toml << EOF

[source.vendored-sources]
directory = "vendor"
EOF

cat >> Cargo.toml << EOF
[profile.release]
lto = true
EOF
%endif

%if 0%{?rhel} == 10
# some weird shit here
sed -i "s|^registry.*||g" .cargo/config.toml
sed -i "s|^replace-with.*|replace-with = \"vendored-sources\"|g" .cargo/config.toml
sed -i "s|^directory = \"\"|directory = \"vendor\"|g" .cargo/config.toml

cat >> Cargo.toml << EOF
[profile.release]
lto = true
EOF
%endif


cp %{SOURCE4} .
cp %{SOURCE5} .

%build

%if 0%{?rhel} == 7
source /opt/rh/llvm-toolset-14.0/enable
%endif

%cargo_build

# man pages
# make -C man

%install
install -d %{buildroot}%{_sysconfdir}/audit/plugins.d
install -d %{buildroot}%{_sysconfdir}/laurel
install -d %{buildroot}%{_localstatedir}/log/laurel
install -m0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/audit/plugins.d/laurel.conf
install -m0644 %{SOURCE3} %{buildroot}%{_sysconfdir}/laurel/config.toml

install -d %{buildroot}%{_sbindir}

%if 0%{?rhel} == 7
install -m0755 target/release/laurel %{buildroot}%{_sbindir}/
install -m0755 target/release/laurel2audit %{buildroot}%{_sbindir}/
%endif

%if 0%{?rhel} == 8
install -m0755 target/rpm/laurel %{buildroot}%{_sbindir}/
install -m0755 target/rpm/laurel2audit %{buildroot}%{_sbindir}/
%endif

%if 0%{?fedora} || 0%{?rhel} >= 9
install -m0755 target/rpm/laurel %{buildroot}%{_sbindir}/
install -m0755 target/rpm/laurel2audit %{buildroot}%{_sbindir}/
%endif

install -d %{buildroot}%{_mandir}/man{7,8}
install -m0644 man/*.7 %{buildroot}%{_mandir}/man7/
install -m0644 man/*.8 %{buildroot}%{_mandir}/man8/

%if %{with check}
%check
%if 0%{?rhel} == 7
source /opt/rh/llvm-toolset-14.0/enable
%endif
%cargo_test
%endif

%post
chcon system_u:object_r:auditd_log_t:s0 %{_localstatedir}/log/laurel

%files
%doc LICENSE README* contrib/selinux
%doc laurel-%{version}-cyclonedx-json
%doc laurel-%{version}-spdx-json
%dir %{_sysconfdir}/laurel
%config(noreplace) %{_sysconfdir}/audit/plugins.d/laurel.conf
%config(noreplace) %{_sysconfdir}/laurel/config.toml
%{_sbindir}/laurel
%{_sbindir}/laurel2audit
%{_mandir}/man7/*
%{_mandir}/man8/*
%dir %{_localstatedir}/log/laurel

%changelog
* Thu Apr 24 2025 Oden Eriksson <oe@nux.se> - 0.7.2-1
- 0.7.2
- new vendor package
- new SBOM files
- new generated manpages

* Fri Mar 14 2025 Oden Eriksson <oe@nux.se> - 0.7.1-2
- disable %%check as it breaks too often

* Fri Mar 14 2025 Oden Eriksson <oe@nux.se> - 0.7.1-1
- 0.7.1

* Wed Jan 29 2025 Oden Eriksson <oe@nux.se> - 0.7.0-1
- 0.7.0
- new vendor package
- new SBOM files (https://github.com/anchore/syft)
- new generated manpages

* Wed Jan 29 2025 Oden Eriksson <oe@nux.se> - 0.6.5-3
- re-enable the test suite
- P1: Remove failures from userdb test (coordinated by Skrzypek Maciej)

* Wed Jan 29 2025 Oden Eriksson <oe@nux.se> - 0.6.5-2
- make check disabled due to https://github.com/threathunters-io/laurel/commit/76b25b6bf17f001d4e6f69bcf674112796fbb4c1

* Mon Jan 27 2025 Oden Eriksson <oe@nux.se> - 0.6.5-1
- 0.6.5
- new vendor package
- new SBOM files (https://github.com/anchore/syft)
- new generated manpages

* Mon Dec 16 2024 Oden Eriksson <oe@nux.se> - 0.6.4-1
- 0.6.4
- new vendor package
- new SBOM files (https://github.com/anchore/syft)
- new generated manpages

* Tue Nov 19 2024 Oden Eriksson <oe@nux.se> - 0.6.3-8
- rebuilt for RHEL 10 beta

* Sun Nov 10 2024 Oden Eriksson <oe@nux.se> - 0.6.3-7
- rebuilt for fedora

* Thu Nov 07 2024 Oden Eriksson <oe@nux.se> - 0.6.3-6
- fix build

* Thu Nov 07 2024 Oden Eriksson <oe@nux.se> - 0.6.3-5
- fix build

* Thu Nov 07 2024 Oden Eriksson <oe@nux.se> - 0.6.3-4
- build release

* Thu Nov 07 2024 Oden Eriksson <oe@nux.se> - 0.6.3-3
- build release

* Thu Nov 07 2024 Oden Eriksson <oe@nux.se> - 0.6.3-2
- build release

* Wed Nov 06 2024 Oden Eriksson <oe@nux.se> - 0.6.3-1.3
- drop invalid macro

* Wed Nov 06 2024 Oden Eriksson <oe@nux.se> - 0.6.3-1.2
- rebuild for RHEL 7

* Fri Oct 18 2024 Oden Eriksson <oe@nux.se> - 0.6.3-1.1
- rebuild for RHEL 8

* Mon Aug 19 2024 Oden Eriksson <oe@nux.se> - 0.6.3-1
- 0.6.3
- newer vendor package
- add the SBOM files

* Thu Jun 27 2024 Oden Eriksson <oe@nux.se> - 0.6.2-3
- rebuilt inhouse

* Thu Jun 27 2024 Oden Eriksson <oe@nux.se> - 0.6.2-2
- drop the selinux sub package and don't run is as _laurel

* Sun Jun 16 2024 Oden Eriksson <oe@nux.se> - 0.6.2-1
- rebuild for RHEL 9 and FC40

* Fri Jun 14 2024 Oden Eriksson <oe@nux.se> - 0.6.2-0.2
- added some of the fedora guidelines

* Thu Jun 13 2024 Oden Eriksson <oe@nux.se> - 0.6.2-0.1
- first blood
